@@ -27,13 +27,14 @@
 
 #include <string.h>
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 
 #include <libmissioncontrol/mc-account.h>
 
+#include <libempathy/empathy-call-factory.h>
 #include <libempathy/empathy-contact-factory.h>
 #include <libempathy/empathy-contact-list.h>
 #include <libempathy/empathy-contact-groups.h>
@@ -213,7 +214,7 @@ contact_list_view_drag_data_received (GtkWidget         *widget,
 		id);
 
 	strv = g_strsplit (id, "/", 2);
-	factory = empathy_contact_factory_new ();
+	factory = empathy_contact_factory_dup_singleton ();
 	account = mc_account_lookup (strv[0]);
 	if (account) {
 		contact = empathy_contact_factory_get_from_id (factory,
@@ -542,7 +543,7 @@ contact_list_view_row_activated (GtkTreeView       *view,
 
 	if (contact) {
 		DEBUG ("Starting a chat");
-		empathy_dispatcher_chat_with_contact (contact);
+		empathy_dispatcher_chat_with_contact (contact, NULL, NULL);
 		g_object_unref (contact);
 	}
 }
@@ -571,7 +572,11 @@ contact_list_view_voip_activated_cb (EmpathyCellRendererActivatable *cell,
 			    -1);
 
 	if (contact) {
-		empathy_dispatcher_call_with_contact (contact);
+		EmpathyCallFactory *factory;
+
+		factory = empathy_call_factory_get ();
+		empathy_call_factory_new_call (factory, contact);
+
 		g_object_unref (contact);
 	}
 }
@@ -792,7 +797,7 @@ contact_list_view_row_has_child_toggled_cb (GtkTreeModel          *model,
 			    EMPATHY_CONTACT_LIST_STORE_COL_NAME, &name,
 			    -1);
 
-	if (!is_group || G_STR_EMPTY (name)) {
+	if (!is_group || EMP_STR_EMPTY (name)) {
 		g_free (name);
 		return;
 	}
