@@ -22,6 +22,9 @@ GType empathy_contact_feature_flags_get_type (void);
 #include <libempathy-gtk/empathy-contact-widget.h>
 #define EMPATHY_TYPE_CONTACT_WIDGET_FLAGS empathy_contact_widget_flags_get_type()
 GType empathy_contact_widget_flags_get_type (void);
+#include <libempathy-gtk/empathy-ui-utils.h>
+#define EMPATHY_TYPE_SOUND empathy_sound_get_type()
+GType empathy_sound_get_type (void);
 G_END_DECLS
 
 #endif /* __LIBEMPATHY_GTK_ENUM_TYPES_H__ */
