@@ -35,16 +35,32 @@
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 
+#include <canberra-gtk.h>
+
 #include <libmissioncontrol/mc-account.h>
 #include <libmissioncontrol/mc-profile.h>
 
+
 #include <libempathy/empathy-contact.h>
 
 #include "empathy-chat-view.h"
 
 G_BEGIN_DECLS
 
-#define G_STR_EMPTY(x) ((x) == NULL || (x)[0] == '\0')
+/* NOTE: Keep this sync with sound_entries in empathy-ui-utils.c */
+typedef enum {
+	EMPATHY_SOUND_MESSAGE_INCOMING = 0,
+	EMPATHY_SOUND_MESSAGE_OUTGOING,
+	EMPATHY_SOUND_CONVERSATION_NEW,
+	EMPATHY_SOUND_CONTACT_CONNECTED,
+	EMPATHY_SOUND_CONTACT_DISCONNECTED,
+	EMPATHY_SOUND_ACCOUNT_CONNECTED,
+	EMPATHY_SOUND_ACCOUNT_DISCONNECTED,
+	EMPATHY_SOUND_PHONE_INCOMING,
+	EMPATHY_SOUND_PHONE_OUTGOING,
+	EMPATHY_SOUND_PHONE_HANGUP,
+	LAST_EMPATHY_SOUND,
+} EmpathySound;
 
 void            empathy_gtk_init                        (void);
 /* Glade */
@@ -85,6 +101,8 @@ GdkPixbuf * empathy_pixbuf_scale_down_if_necessary      (GdkPixbuf        *pixbu
 							 gint              max_size);
 GdkPixbuf * empathy_pixbuf_from_icon_name               (const gchar      *icon_name,
 							 GtkIconSize       icon_size);
+GdkPixbuf * empathy_pixbuf_from_icon_name_sized         (const gchar      *icon_name,
+							 gint              size);
 /* Text view */
 gboolean    empathy_text_iter_forward_search            (const GtkTextIter*iter,
 							 const gchar      *str,
@@ -114,6 +132,15 @@ GtkWidget * empathy_link_button_new                     (const gchar      *url,
 
 void        empathy_send_file_with_file_chooser         (EmpathyContact   *contact);
 
+/* Sounds */
+void        empathy_sound_play                          (GtkWidget        *widget,
+							 EmpathySound      sound_id);
+gboolean    empathy_sound_play_full                     (GtkWidget *widget,
+							 EmpathySound sound_id,
+							 ca_finish_callback_t callback,
+							 gpointer user_data);
+void        empathy_sound_stop                          (EmpathySound sound_id);
+
 G_END_DECLS
 
 #endif /*  __EMPATHY_UI_UTILS_H__ */
