@@ -26,6 +26,8 @@
 
 #include <libmissioncontrol/mc-account.h>
 
+#include <libempathy/empathy-tp-chat.h>
+
 G_BEGIN_DECLS
 
 #define EMPATHY_TYPE_CHATROOM             (empathy_chatroom_get_type ())
@@ -50,9 +52,8 @@ struct _EmpathyChatroomClass {
 };
 
 GType            empathy_chatroom_get_type        (void) G_GNUC_CONST;
-EmpathyChatroom *empathy_chatroom_new             (McAccount       *account,
-						   const gchar     *room);
-EmpathyChatroom *empathy_chatroom_new_full         (McAccount      *account,
+EmpathyChatroom *empathy_chatroom_new             (McAccount       *account);
+EmpathyChatroom *empathy_chatroom_new_full        (McAccount       *account,
 						   const gchar     *room,
 						   const gchar     *name,
 						   gboolean         auto_connect);
@@ -70,8 +71,8 @@ void            empathy_chatroom_set_auto_connect (EmpathyChatroom *chatroom,
 						   gboolean         auto_connect);
 gboolean        empathy_chatroom_equal            (gconstpointer    v1,
 						   gconstpointer    v2);
+EmpathyTpChat * empathy_chatroom_get_tp_chat      (EmpathyChatroom *chatroom);
 
-
-G_BEGIN_DECLS
+G_END_DECLS
 
 #endif /* __EMPATHY_CHATROOM_H__ */
