@@ -117,7 +117,7 @@ log_manager_constructor (GType type,
 			(type, n_props, props);
 
 		manager_singleton = EMPATHY_LOG_MANAGER (retval);
-		g_object_add_weak_pointer (retval, (gpointer *) &manager_singleton);
+		g_object_add_weak_pointer (retval, (gpointer) &manager_singleton);
 	}
 
 	return retval;
