@@ -43,6 +43,8 @@
 #include "empathy-time.h"
 #include "empathy-utils.h"
 
+#include "extensions/extensions.h"
+
 #define DEBUG_FLAG EMPATHY_DEBUG_FT
 #include "empathy-debug.h"
 
@@ -352,12 +354,10 @@ tp_file_finalize (GObject *object)
 
   if (tp_file->priv->channel)
     {
-      DEBUG ("Closing channel..");
       g_signal_handlers_disconnect_by_func (tp_file->priv->channel,
           tp_file_invalidated_cb, object);
-      tp_cli_channel_call_close (tp_file->priv->channel, -1, NULL, NULL,
-          NULL, NULL);
       g_object_unref (tp_file->priv->channel);
+      tp_file->priv->channel = NULL;
     }
 
   if (tp_file->priv->factory)
@@ -507,8 +507,8 @@ tp_file_constructor (GType type,
 
   tp_file = EMPATHY_TP_FILE (file_obj);
 
-  tp_file->priv->factory = empathy_contact_factory_new ();
-  tp_file->priv->mc = empathy_mission_control_new ();
+  tp_file->priv->factory = empathy_contact_factory_dup_singleton ();
+  tp_file->priv->mc = empathy_mission_control_dup_singleton ();
 
   g_signal_connect (tp_file->priv->channel, "invalidated",
     G_CALLBACK (tp_file_invalidated_cb), tp_file);
@@ -753,6 +753,9 @@ tp_file_method_cb (TpProxy *proxy,
   tp_file->priv->unix_socket_path = g_value_dup_string (address);
 
   DEBUG ("Got unix socket path: %s", tp_file->priv->unix_socket_path);
+
+  if (tp_file->priv->state == EMP_FILE_TRANSFER_STATE_OPEN)
+    tp_file_start_transfer (tp_file);
 }
 
 /**
@@ -845,9 +848,9 @@ empathy_tp_file_is_incoming (EmpathyTpFile *tp_file)
   return tp_file->priv->incoming;
 }
 
-EmpFileTransferState
+guint
 empathy_tp_file_get_state (EmpathyTpFile *tp_file,
-                           EmpFileTransferStateChangeReason *reason)
+                           guint *reason)
 {
   g_return_val_if_fail (EMPATHY_IS_TP_FILE (tp_file),
       EMP_FILE_TRANSFER_STATE_NONE);
@@ -910,12 +913,20 @@ empathy_tp_file_cancel (EmpathyTpFile *tp_file)
 {
   g_return_if_fail (EMPATHY_IS_TP_FILE (tp_file));
 
-  tp_cli_channel_call_close (tp_file->priv->channel, -1, NULL, NULL, NULL, NULL);
+  DEBUG ("Closing channel..");
+  tp_cli_channel_call_close (tp_file->priv->channel, -1,
+    NULL, NULL, NULL, NULL);
 
   if (tp_file->priv->cancellable != NULL)
     g_cancellable_cancel (tp_file->priv->cancellable);
 }
 
+void
+empathy_tp_file_close (EmpathyTpFile *tp_file)
+{
+  empathy_tp_file_cancel (tp_file);
+}
+
 static void
 empathy_tp_file_class_init (EmpathyTpFileClass *klass)
 {
